'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _express = require('express');

var _express2 = _interopRequireDefault(_express);

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _sentry = require('./sentry');

var _sentry2 = _interopRequireDefault(_sentry);

var _storyboard = require('./storyboard');

var _storyboard2 = _interopRequireDefault(_storyboard);

var _cookieParser = require('cookie-parser');

var _cookieParser2 = _interopRequireDefault(_cookieParser);

var _bodyParser = require('body-parser');

var _bodyParser2 = _interopRequireDefault(_bodyParser);

var _routes = require('./routes');

var _routes2 = _interopRequireDefault(_routes);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var port = process.env.PORT || 4444;
var app = (0, _express2.default)();
var router = _express2.default.Router(); // eslint-disable-line new-cap

if (_sentry2.default) {
    app.use(_sentry2.default.requestHandler());
}

app.use(_bodyParser2.default.json());
app.use(_bodyParser2.default.urlencoded({ extended: true }));
app.use((0, _cookieParser2.default)());

router.use(function (req, res, next) {
    req.story = _storyboard2.default.child({
        src: 'request',
        title: 'Express',
        level: 'INFO'
    });
    req.story.info('Incoming request', req.path);

    var end = res.end.bind(res);
    res.end = function () {
        req.story.close();
        end.apply(undefined, arguments);
    };

    next();
});

(0, _routes2.default)(router);
app.use('/', router);

if (_sentry2.default) {
    app.use(_sentry2.default.errorHandler());
}

app.use(function (err, req, res, next) {
    // eslint-disable-line no-unused-vars
    (req.story || _storyboard2.default).error('Unhandled error', { attach: err });
    res.end('Internal server error');
});

var server = _http2.default.createServer(app);
server.on('listening', function () {
    _storyboard2.default.info('Express server is listening on port ' + server.address().port);
});
server.on('error', function (error) {
    if (error.syscall !== 'listen') {
        throw error;
    }
    switch (error.code) {
        case 'EACCES':
            _storyboard2.default.error('Port ' + port + ' requires elevated privileges');
            process.exit(1);
            break;
        case 'EADDRINUSE':
            _storyboard2.default.error('Port ' + port + ' is already in use');
            process.exit(1);
            break;
        default:
            throw error;
    }
});
server.listen(port);

exports.default = app;
//# sourceMappingURL=server.js.map